@@ -187,12 +187,16 @@ signals:
     // A new folder was discovered and was not synced because of the confirmation feature
     void newBigFolder(const QString &folder, bool isExternal);
 
+    void existingFolderNowBig(const QString &folder);
+
     /** Emitted when propagation has problems with a locked file.
      *
      * Forwarded from OwncloudPropagator::seenLockedFile.
      */
     void seenLockedFile(const QString &fileName);
 
+    void lockFileDetected(const QString &lockFile);
+
 private slots:
     void slotFolderDiscovered(bool local, const QString &folder);
     void slotRootEtagReceived(const QByteArray &, const QDateTime &time);
@@ -210,9 +214,10 @@ private slots:
 
     void slotItemCompleted(const OCC::SyncFileItemPtr &item, const OCC::ErrorCategory category);
     void slotDiscoveryFinished();
-    void slotPropagationFinished(bool success);
+    void slotPropagationFinished(SyncFileItem::Status status);
     void slotProgress(const OCC::SyncFileItem &item, qint64 current);
     void slotCleanPollsJobAborted(const QString &error, const OCC::ErrorCategory category);
+    void detectFileLock(const OCC::SyncFileItemPtr &item);
 
     /** Records that a file was touched by a job. */
     void slotAddTouchedFile(const QString &fn);
